@@ -7,6 +7,7 @@ from .api import (
     BatchCollection,
     BatchRequest,
     BatchRequestStatus,
+    BatchStatisticalRequest,
     BatchTileStatus,
     BatchUserAction,
     ByocCollection,
@@ -15,6 +16,7 @@ from .api import (
     ByocTile,
     FisRequest,
     SentinelHubBatch,
+    SentinelHubBatchStatistical,
     SentinelHubBYOC,
     SentinelHubCatalog,
     SentinelHubRequest,
@@ -24,6 +26,8 @@ from .api import (
     WmsRequest,
     monitor_batch_analysis,
     monitor_batch_job,
+    monitor_batch_statistical_analysis,
+    monitor_batch_statistical_job,
     opensearch,
 )
 from .api.opensearch import get_area_dates, get_area_info, get_tile_info, get_tile_info_id
@@ -48,7 +52,7 @@ from .constants import (
     ServiceUrl,
     SHConstants,
 )
-from .data_collections import DataCollection, DataSource
+from .data_collections import DataCollection
 from .data_collections_bands import Band, Unit
 from .download import (
     DownloadClient,
