@@ -1,16 +1,19 @@
 """
 The part of the package that implements interface with Sentinel Hub services.
 """
-
 from .batch import (
     BatchCollection,
     BatchRequest,
     BatchRequestStatus,
+    BatchStatisticalRequest,
     BatchTileStatus,
     BatchUserAction,
     SentinelHubBatch,
+    SentinelHubBatchStatistical,
     monitor_batch_analysis,
     monitor_batch_job,
+    monitor_batch_statistical_analysis,
+    monitor_batch_statistical_job,
 )
 from .byoc import ByocCollection, ByocCollectionAdditionalData, ByocCollectionBand, ByocTile, SentinelHubBYOC
 from .catalog import SentinelHubCatalog
