@@ -11,12 +11,13 @@ import requests
 from requests import Response
 
 from ..config import SHConfig
+from ..constants import SHConstants
 from ..exceptions import SHRateLimitWarning, SHRuntimeWarning
 from ..type_utils import JsonDict
 from .client import DownloadClient
 from .handlers import fail_user_errors, retry_temporary_errors
+from .models import DownloadRequest, DownloadResponse
 from .rate_limit import SentinelHubRateLimit
-from .request import DownloadRequest
 from .session import SentinelHubSession
 
 LOGGER = logging.getLogger(__name__)
@@ -64,7 +65,7 @@ class SentinelHubDownloadClient(DownloadClient):
 
     @retry_temporary_errors
     @fail_user_errors
-    def _execute_download(self, request: DownloadRequest) -> bytes:
+    def _execute_download(self, request: DownloadRequest) -> DownloadResponse:
         """
         Executes the download with a single thread and uses a rate limit object, which is shared between all threads
         """
@@ -89,7 +90,7 @@ class SentinelHubDownloadClient(DownloadClient):
                 response.raise_for_status()
 
                 LOGGER.debug("Successful %s request to %s", request.request_type.value, request.url)
-                return response.content
+                return DownloadResponse.from_response(response, request)
 
             LOGGER.debug("Request needs to wait. Sleeping for %0.2f", sleep_time)
             time.sleep(sleep_time)
@@ -116,12 +117,15 @@ class SentinelHubDownloadClient(DownloadClient):
         )
 
     def _prepare_headers(self, request: DownloadRequest) -> JsonDict:
-        """Prepares final headers by potentially joining them with session headers"""
-        if not request.use_session:
-            return request.headers
+        """Prepares final headers by potentially joining them with session headers. Note that in the current
+        implementation of this method request headers have priority to overwrite default and session headers with the
+        same keys.
+        """
+        session_headers: JsonDict = {}
+        if request.use_session:
+            session_headers = self._execute_thread_safe(self._get_session_headers)
 
-        session_headers = self._execute_thread_safe(self._get_session_headers)
-        return {**session_headers, **request.headers}
+        return {**SHConstants.HEADERS, **session_headers, **request.headers}
 
     def _get_session_headers(self) -> JsonDict:
         """Provides up-to-date session headers
